@@ -3,21 +3,21 @@ Demonstrates how to use the gevent compatible scheduler to schedule a job that e
 intervals.
 """
 
-from datetime import datetime
 import os
+from datetime import datetime
 
 from apscheduler.schedulers.gevent import GeventScheduler
 
 
 def tick():
-    print('Tick! The time is: %s' % datetime.now())
+    print(f"Tick! The time is: {datetime.now()}")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     scheduler = GeventScheduler()
-    scheduler.add_job(tick, 'interval', seconds=3)
+    scheduler.add_job(tick, "interval", seconds=3)
     g = scheduler.start()  # g is the greenlet that runs the scheduler loop
-    print('Press Ctrl+{0} to exit'.format('Break' if os.name == 'nt' else 'C'))
+    print("Press Ctrl+{} to exit".format("Break" if os.name == "nt" else "C"))
 
     # Execution will block here until Ctrl+C (Ctrl+Break on Windows) is pressed.
     try:
